import Rhino
import scriptcontext
import rhinoscriptsyntax as rs
import System

def SetupDimensionStyle(style_name):
    
    # try to locate the dimension style
    dim_style = scriptcontext.doc.DimStyles.Find(style_name, True)
    
    if not dim_style:
        
        # create the new dimension style
        dim_style = Rhino.DocObjects.DimensionStyle()
        
        dim_style.AlternateBelowLine = False
        dim_style.AlternateDimensionLengthDisplay = Rhino.DocObjects.DimensionStyle.LengthDisplay.InchesDecimal  
        dim_style.AlternateLengthFactor = 1.0
        dim_style.AlternateLengthResolution = 2
        dim_style.AlternatePrefix = "["
        dim_style.AlternateRoundoff = 0.0
        dim_style.AlternateSuffix = "]"
        dim_style.AlternateToleranceResolution = 4
        dim_style.AlternateUnitsDisplay = False
        dim_style.AlternateZeroSuppress = Rhino.DocObjects.DimensionStyle.ZeroSuppression.None
        dim_style.AngleFormat = Rhino.DocObjects.DimensionStyle.AngleDisplayFormat.DecimalDegrees
        dim_style.AngleResolution = 1
        dim_style.AngleZeroSuppress = Rhino.DocObjects.DimensionStyle.ZeroSuppression.None
        dim_style.AngularRoundoff = 0.0
        dim_style.ArcLengthSymbol = 0
        dim_style.ArrowBlockId1 = System.Guid.Empty
        dim_style.ArrowBlockId2 =  System.Guid.Empty
        dim_style.ArrowLength = 3.0
        dim_style.ArrowType1 = Rhino.DocObjects.DimensionStyle.ArrowType.SolidTriangle
        dim_style.ArrowType2 = Rhino.DocObjects.DimensionStyle.ArrowType.SolidTriangle
        
        dim_style.BaselineSpacing = 7.5
        
        dim_style.CenterMarkType = Rhino.DocObjects.DimensionStyle.CenterMarkStyle.Mark
        dim_style.CentermarkSize = 2.5
        
        dim_style.DimRadialTextAngleType = Rhino.DocObjects.DimensionStyle.LeaderContentAngleStyle.Horizontal  
        dim_style.DimRadialTextLocation = Rhino.DocObjects.DimensionStyle.TextLocation.InDimLine  
        dim_style.DimRadialTextOrientation = Rhino.DocObjects.TextOrientation.InPlane
        dim_style.DimTextAngleType = Rhino.DocObjects.DimensionStyle.LeaderContentAngleStyle.Aligned
        dim_style.DimTextLocation = Rhino.DocObjects.DimensionStyle.TextLocation.InDimLine # AboveDimLine
        dim_style.DimTextOrientation = Rhino.DocObjects.TextOrientation.InPlane
        dim_style.DimensionLengthDisplay = Rhino.DocObjects.DimensionStyle.LengthDisplay.ModelUnits
        dim_style.DimensionLineExtension = 0.0
        dim_style.DimensionScale = 1.0
        dim_style.DimensionScaleValue = Rhino.ScaleValue.OneToOne()
        dim_style.DrawForward = True
        dim_style.DrawTextMask = False
        
        dim_style.ExtensionLineExtension = 1.0
        dim_style.ExtensionLineOffset = 0.0 # 0.5
        
        # dim_style.FitArrow = Rhino.DocObjects.DimensionStyle.ArrowFit.Auto (FRANK ERROR)
        # dim_style.FitText = Rhino.DocObjects.DimensionStyle.TextFit.Auto (FRANK ERROR)
        dim_style.FixedExtensionLength = 1.0
        dim_style.FixedExtensionOn = False
        dim_style.Font = Rhino.DocObjects.Font("Arial")
        # dim_style.ForceDimensionLineBetweenExtensionLines = True (FRANK ERROR)
        
        dim_style.LeaderArrowBlockId = System.Guid.Empty
        dim_style.LeaderArrowLength = 3.0
        dim_style.LeaderArrowType = Rhino.DocObjects.DimensionStyle.ArrowType.SolidTriangle
        dim_style.LeaderContentAngleType = Rhino.DocObjects.DimensionStyle.LeaderContentAngleStyle.Horizontal
        dim_style.LeaderCurveType = Rhino.DocObjects.DimensionStyle.LeaderCurveStyle.Polyline
        dim_style.LeaderHasLanding = False
        dim_style.LeaderLandingLength = 2.5
        dim_style.LeaderTextHorizontalAlignment = Rhino.DocObjects.TextHorizontalAlignment.Left
        dim_style.LeaderTextOrientation = Rhino.DocObjects.TextOrientation.InPlane
        dim_style.LeaderTextRotationDegrees = 0.0
        dim_style.LeaderTextRotationRadians = 0.0
        dim_style.LeaderTextVerticalAlignment = Rhino.DocObjects.TextVerticalAlignment.MiddleOfTop
        dim_style.LengthFactor = 1.0
        dim_style.LengthResolution = 2
        
        dim_style.MaskColor = System.Drawing.Color.FromArgb(255, 255, 255, 255)
        dim_style.MaskColorSource = Rhino.DocObjects.DimensionStyle.MaskType.BackgroundColor  
        dim_style.MaskOffset = 0.8
        
        dim_style.Name = style_name
        
        dim_style.ParentId = System.Guid.Empty
        dim_style.Prefix = System.String.Empty
        
        dim_style.Roundoff = 0.0
        
        dim_style.ScaleLeftLengthMillimeters = 1.0
        dim_style.ScaleRightLengthMillimeters = 1.0
        dim_style.StackFractionFormat = Rhino.DocObjects.DimensionStyle.StackDisplayFormat.StackHorizontal
        dim_style.StackHeightScale = 0.7
        dim_style.Suffix = System.String.Empty
        dim_style.SuppressArrow1 = False
        dim_style.SuppressArrow2 = False
        dim_style.SuppressExtension1 = False
        dim_style.SuppressExtension2 = False
        
        dim_style.TextGap = 0.8
        dim_style.TextHeight = 2.5
        dim_style.TextHorizontalAlignment = Rhino.DocObjects.TextHorizontalAlignment.Left
        dim_style.TextMoveLeader = 0
        dim_style.TextOrientation = Rhino.DocObjects.TextOrientation.InPlane
        dim_style.TextRotation = 0.0
        dim_style.TextUnderlined = False
        dim_style.TextVerticalAlignment = Rhino.DocObjects.TextVerticalAlignment.Top
        dim_style.ToleranceFormat = Rhino.DocObjects.DimensionStyle.ToleranceDisplayFormat.None
        dim_style.ToleranceHeightScale = 0.7
        dim_style.ToleranceLowerValue = 0.0
        dim_style.ToleranceResolution = 4
        dim_style.ToleranceUpperValue = 0.0
        dim_style.ToleranceZeroSuppress = Rhino.DocObjects.DimensionStyle.ZeroSuppression.None
        
        dim_style.ZeroSuppress = Rhino.DocObjects.DimensionStyle.ZeroSuppression.None
        
        # add the dimension style to the table, get the index
        style_index = scriptcontext.doc.DimStyles.Add(dim_style, False)
        if style_index < 0:
            print "Error - failed to add dimension style '{}' to document".format(dim_style.Name)
            return
        
    else:
        
        # index of existing style
        style_index = dim_style.Index
    
    # make the dim_style current
    rc = scriptcontext.doc.DimStyles.SetCurrent(style_index, False)
    if not rc:
        print "Error - failed to make dimension style '{}' current".format(dim_style.Index)
        return
    
    return True

if __name__=="__main__":
    SetupDimensionStyle("TestStyle")
